//
//  DBAccess.m
//  sqlitedemo1
//
//  Created by rutger_i on 3/11/12.
//  Copyright (c) 2012 __MyCompanyName__. All rights reserved.
//

#import "DBAccess.h"
#import "Patient.h"

@implementation DBAccess

#pragma mark Class functions
+ (NSString *) getDBPath {
    NSArray *paths = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory , NSUserDomainMask, YES);
	NSString *documentsDir = [paths objectAtIndex:0];
	return [documentsDir stringByAppendingPathComponent:@"demodatabase-1_0.sql"];
}

+ (void) copyDatabaseIfNeeded {
	NSFileManager *fileManager = [NSFileManager defaultManager];
	NSError *error;
	NSString *dbPath = [DBAccess getDBPath];
	BOOL success = [fileManager fileExistsAtPath:dbPath];
	
	if(!success) {
		
		NSString *defaultDBPath = [[[NSBundle mainBundle] resourcePath] stringByAppendingPathComponent:@"demodatabase-1_0.sql"];
		success = [fileManager copyItemAtPath:defaultDBPath toPath:dbPath error:&error];
		
		if (!success)
			NSAssert1(0, @"Failed to create writable database file with message '%@'.", [error localizedDescription]);
	}
}

#pragma mark Database Query functions

- (NSArray *) getPatients
{
    sqlite3 *database;
    sqlite3_open([[DBAccess getDBPath] UTF8String], &database);
    NSMutableArray *result = [[NSMutableArray alloc]init] ;

    NSString *sql = @"SELECT PATIENTNR, NAME, GENDER, datetime(DATEOFBIRTH, 'unixepoch', 'localtime')  FROM PATIENTS";
    sqlite3_stmt * statement;

    int sqlResult = sqlite3_prepare_v2(database, [sql UTF8String], -1, &statement, NULL);

    if(sqlResult == SQLITE_OK)
    {        
        while(sqlite3_step(statement) == SQLITE_ROW)
        {
            Patient *p = [[Patient alloc] init];
            [p setPatientnr: sqlite3_column_int(statement, 0)];
            [p setName:[NSString stringWithUTF8String:(char *) sqlite3_column_text(statement, 1)]];
            [p setGender: sqlite3_column_int(statement, 2) == 0? @"Female":@"Male"];
            [p setDateofbirth:[NSString stringWithUTF8String:(char *) sqlite3_column_text(statement, 3)]];
        
            [result addObject: p];
        }
    } else
    {
        result = nil;
        printf( "could not prepare statemnt: %s\n", sqlite3_errmsg(database) ); 
    }
    
    sqlite3_reset(statement);
    sqlite3_finalize(statement);

    sqlite3_close(database);

    return result;
}

@end
